@@ -4,23 +4,23 @@ from django.db import models
 class ModelAddressBase(models.Model):
 
     street = models.CharField(
-        ('address_street'),
+        'address_street',
         max_length=254,
         blank=False,
     )
     number = models.PositiveSmallIntegerField(
-        ('address_number'),
+        'address_number',
         blank=False,
     )
     department = models.CharField(
-        ('address_department'),
+        'address_department',
         max_length=254,
         blank=True,
         null=True,
         default=''
     )
     flat = models.CharField(
-        ('address_flat'),
+        'address_flat',
         max_length=254,
         blank=True,
         null=True,
@@ -29,9 +29,19 @@ class ModelAddressBase(models.Model):
 
     class Meta:
 
-        verbose_name = 'Address'
-        verbose_name_plural = 'Addresses'
         abstract = True
 
     def __str__(self):
         return f"{self.street} {self.number} {self.department} {self.flat}"
+
+
+class AbstractNameModel(models.Model):
+    name = models.CharField(
+        'Nombre',
+        max_length=100,
+        primary_key=True
+        )
+
+    class Meta:
+
+        abstract = True
